@@ -6,9 +6,9 @@ from bs4 import BeautifulSoup
 from requests import get
 from string_utils.validation import is_integer
 
-import utils
 from sinta_scraper.dept_scraper import dept_authors
 from utils.config import get_config
+from utils.utils import cast, format_output, listify
 
 
 def author_scopus_docs(author_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
@@ -18,7 +18,7 @@ def author_scopus_docs(author_id, output_format='dictionary', pretty_print=None,
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
     page_info = soup.select('.uk-width-large-1-2.table-footer')
-    n_page = utils.cast(page_info[0].text.strip().split()[3])
+    n_page = cast(page_info[0].text.strip().split()[3])
     worker_result = parse(soup)
     date_format = '%Y-%m-%d'
 
@@ -34,7 +34,7 @@ def author_scopus_docs(author_id, output_format='dictionary', pretty_print=None,
         max_date_parsed = datetime.strptime(max_date, date_format)
         worker_result = [doc for doc in worker_result if datetime.strptime(doc['date'], date_format) <= max_date_parsed]
 
-    return utils.format_output(worker_result, output_format, pretty_print, xml_library)
+    return format_output(worker_result, output_format, pretty_print, xml_library)
 
 
 def author_scopus_journal_docs(author_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
@@ -42,7 +42,7 @@ def author_scopus_journal_docs(author_id, output_format='dictionary', pretty_pri
     docs = author_scopus_docs(author_id, min_date=min_date, max_date=max_date, max_workers=max_workers)
     journal_docs = [doc for doc in docs if doc['type'] == 'Journal']
 
-    return utils.format_output(journal_docs, output_format, pretty_print, xml_library)
+    return format_output(journal_docs, output_format, pretty_print, xml_library)
 
 
 def author_scopus_conference_docs(author_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
@@ -50,7 +50,7 @@ def author_scopus_conference_docs(author_id, output_format='dictionary', pretty_
     docs = author_scopus_docs(author_id, min_date=min_date, max_date=max_date, max_workers=max_workers)
     journal_docs = [doc for doc in docs if doc['type'].startswith('Conference')]
 
-    return utils.format_output(journal_docs, output_format, pretty_print, xml_library)
+    return format_output(journal_docs, output_format, pretty_print, xml_library)
 
 
 def worker(author_id, page, worker_result):
@@ -85,8 +85,8 @@ def parse(soup):
             'publisher': info2[0].strip(),
             'date': info2[3].strip(),
             'type': info2[4].strip(),
-            'quartile': utils.cast(quartile[1]) if re.search(r'^Q[1-4]{1}$', quartile) else '-',
-            'citations': utils.cast(citations) if is_integer(citations) else 0
+            'quartile': cast(quartile[1]) if re.search(r'^Q[1-4]{1}$', quartile) else '-',
+            'citations': cast(citations) if is_integer(citations) else 0
         })
 
     return result
@@ -94,8 +94,7 @@ def parse(soup):
 
 def dept_scopus_docs(dept_ids, affil_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
                      max_workers=None):
-    if type(dept_ids) is not list and type(dept_ids) is not tuple:
-        dept_ids = [dept_ids]
+    dept_ids = listify(dept_ids)
 
     authors = []
     worker_result = []
@@ -107,7 +106,7 @@ def dept_scopus_docs(dept_ids, affil_id, output_format='dictionary', pretty_prin
         for author in authors:
             executor.submit(dept_scopus_docs_worker, author['id'], worker_result)
 
-    return utils.format_output(worker_result, output_format, pretty_print, xml_library)
+    return format_output(worker_result, output_format, pretty_print, xml_library)
 
 
 def dept_scopus_docs_worker(author_id, worker_result):
