@@ -1,6 +1,7 @@
 import json
-from dicttoxml import dicttoxml
+
 from dict2xml import dict2xml
+from dicttoxml import dicttoxml
 from string_utils.validation import is_integer, is_decimal
 
 
@@ -34,3 +35,7 @@ def cast(string: str):
         return None
     else:
         return string
+
+
+def listify(param):
+    return [param] if type(param) not in [list, tuple] else param
